%% Optimal Allocations
% First impose DIC and ex-post verify that all LDIC binding and UIC satisfied, else impose UIC as well.
% Quasi-linear utility specifications (1) to (4) in Table B4

clc
clear all

global w z pz Nz N p theta gamma G cons

w=0.51;                                                     % Cost of formal child care based on 2010 average child care cost
z=0.1*[2.40 3.75 4.08 4.32 4.54 4.72 4.85 4.97 5.08 5.19 5.29 5.43 5.54 5.63 5.76 5.88 6 6.13 6.23 6.36 6.5 6.66 6.8 7.02 7.21 7.34 7.52 7.71 8.01 8.33 8.69 9 9.37 9.61 10 10.31 10.83 11.53 12.01 12.5 13.46 14 14.57 15.71 16.82 18.51 20 22.36 25.64 32.21];
                                                            % Market productivity type (normalised by dividing by 10)
Nz=50;
N=51;
cons=0;                                                     % In 1e34 specification, need to scale utility by a small constant to avoid negative utility within log social welfare

%% e=24 ; gamma=1 ; w=0.51                                    
n=24;                                                       % Normalisation
gamma=1;                                                    % Effort felicity parameter
G=(3896)/(10*50*n);                                         % Government generosity when w=0.51
theta=1.27;                                                 % Effort cost type types

%% e=34 ; gamma=1 ; w=0.51
% n=34;                                                       % Normalisation
% gamma=1;                                                    % Effort felicity parameter
% G=(4309)/(10*50*n);                                         % Government generosity 
% theta=0.88;                                                 % Effort cost type types
% cons=0.1;                                                   % Scale utility by a small constant to avoid negative utility within log social welfare

%% e=24 ; gamma=1 ; w=0.64
% n=24;                                                       % Normalisation
% gamma=1;                                                    % Effort felicity parameter
% G=(4141)/(10*50*n);                                         % Government generosity when w=0.51
% theta=1.27;                                                 % Effort cost type types
% w=0.64;

%% e=24 ; gamma=2 ; w=0.51
% n=24;                                                       % Normalisation
% gamma=2;                                                    % Effort felicity parameter
% G=(4275)/(10*50*n);                                         % Government generosity 
% theta=1.71;                                                 % Effort cost type types

%% Empirical distributions
pz=0.02*ones(Nz,1);                                         % Distribution of z based on 2010 March CPS z distribution
p=0.11;                                                     % Probability of being unlucky

%% Optimisation

options=optimset('LargeScale','on','MaxFunEvals',1000000,'Display','Iter','MaxIter',100000,'TolCon',1e-6,'TolX',1e-6);
% options=optimset('LargeScale','on','MaxFunEvals',10000000,'Display','Iter','MaxIter',1000000);

% Initial values
init=0.5*ones(N,3);
% lb=1e-5*ones(N,3);
ub=100*ones(N,3);
for i=1:N
    ub(i,2)=1;
end

% e=24 ; gamma=1 ; w=0.51 ; Tol=1e-6
init=[0.433780221849438 0.647388789948975 1.93339694207784e-06;0.433394440207198 0.64577577209545 7.24557160637066e-05;0.432833414355463 0.642963722151847 0.000228701942785253;0.438201173255022 0.652560926746961 0.000349657473697817;0.451768846835476 0.67685038705922 0.000490589701780613;0.440424041667834 0.653730651767054 0.000687411976358133;0.439883617125595 0.65102961087097 0.000921906653302354;0.438643810291833 0.646675820643999 0.0013202873365874;0.438505252853651 0.644435474347604 0.00178868149245717;0.43846212629631 0.642024566745288 0.00251653995237695;0.438692899117995 0.638759464042697 0.00407257186211047;0.43883531789173 0.635045743071514 0.00590798864137825;0.438313036176227 0.604744707300621 0.0216505543199493;0.436123452965852 0.53830500265393 0.0559703155806213;0.431258116523735 0.471593523937656 0.0879697452654621;0.406040875736762 0.0142135302347264 0.320496139843278;0.421210400527564 0.00487585738906775 0.345608149950414;0.427724728056523 0.0041857700129647 0.354413809194203;0.438343816095195 0.00403097609622315 0.368380058614614;0.442555924550292 0.00347952988750739 0.374222293250886;0.447506107439 0.00268992462435877 0.381361935426173;0.462030383481491 0.00262294479057002 0.401186368250612;0.475820355404462 0.00229378231471679 0.420201769298985;0.478488511874904 0.00218858363871649 0.423926372011285;0.500624251140342 0.00177331016263019 0.455578513156217;0.523532382666232 0.001418781136508 0.487781845201152;0.528355164960143 0.00135400155835915 0.494493448280984;0.539924408158015 0.0012976114951555 0.510988939423274;0.543151923825575 0.00131465245947289 0.515670708127207;0.553819215719163 0.00114175152256326 0.532323487931764;0.568902094738836 0.00102379254826045 0.556750420383278;0.612950677297623 0.000819750701264122 0.628100313621878;0.628795578716855 0.00074065644059042 0.653542026895751;0.696584390943322 0.000609186733716339 0.760442833451542;0.698549064979414 0.00059260510654804 0.763439264713836;0.740740092826936 0.000533807093465017 0.830633685821635;0.742755083847715 0.000520190446795299 0.833868720430804;0.750136652533639 0.000488859592827905 0.846926370052161;0.877879261563086 0.000389897458180529 1.07169714764;0.913123372878501 0.000362191123311458 1.13030133816122;0.914313333717976 0.000350439637666668 1.132346703989;1.18231887150588 0.000269556708623215 1.58595800832516;1.24637364267345 0.000254492344607 1.68344698133415;1.24822815164116 0.000247880100867683 1.68636298459107;1.44247124570113 0.000214869327752594 2.0152392474476;1.53721557609512 0.000198005714814816 2.17755117442657;2.03966188491997 0.000158663246165378 3.01888903957744;2.30661166457056 0.000142732080036053 3.43878884199907;3.0068407083632 0.000118158167775949 4.55153654422513;4.17621443207207 9.47890818181678e-05 6.34356666143887;9.21241881792323 6.2478019834168e-05 13.1509927155489];
% e=34 ; gamma=1 ; w=0.51 ; Tol=1e-6
% init=[0.173168820606108 0.443697508874067 1.77188684379577e-07;0.175841045622807 0.448564363964495 3.97342325232557e-05;0.175372324146072 0.446987095624083 0.000147891136979963;0.173044999788206 0.441748426768021 0.000211629164191616;0.175762432080948 0.446304798882737 0.000276325200356284;0.17446512268425 0.442915063254014 0.000382194918259196;0.175937331843171 0.444902434380367 0.000514389387609532;0.175527216913223 0.443249188408757 0.000646069740675154;0.175483211269653 0.442263354604012 0.000829277844110039;0.17547961149835 0.441293819858054 0.00108112121172117;0.175554308157992 0.440196599370575 0.00152508079551567;0.17551358032007 0.438687493433489 0.00212393315912544;0.175237373616747 0.428790026813724 0.00710756588562319;0.174098061829639 0.398130601345895 0.0227941471172385;0.171725283307399 0.379402445943243 0.030637296870261;0.162043451363856 0.17704547075385 0.135685305454323;0.15561374975769 0.0279949302807144 0.215097758129569;0.158995516213417 0.00668792447416443 0.232381531168041;0.170229037481713 0.0030927979232734 0.249613411654125;0.173348762312929 0.00259360532761253 0.25405329703742;0.178119470115221 0.00216695376393126 0.260782726086951;0.182536964709118 0.00185503664746342 0.267082607932667;0.189817671795738 0.00154448733471483 0.277540617575259;0.19096164465777 0.00146550613331841 0.279216045100301;0.204272873400357 0.00114291833097985 0.29909296494545;0.223969337437327 0.000886495769375643 0.327618915844513;0.226291435522665 0.00085208641768856 0.330921345793093;0.229640490172128 0.000804498876014296 0.3358658277369;0.230598148045676 0.000776890603342667 0.337329213111765;0.236219196667031 0.000709149111384717 0.346518342746547;0.244835906231609 0.000634135314813606 0.361234278964968;0.27773647235527 0.000498244327884617 0.41682218027406;0.286272661816259 0.000461998352687575 0.431009798153596;0.339669815894843 0.000363618211258057 0.51705284996404;0.340826018979337 0.00035571571256438 0.518830609866001;0.365067127140876 0.000321248896517533 0.557987285977454;0.366115560593085 0.000312690082082124 0.559704787237354;0.368646208151563 0.000297774875736898 0.564283921698816;0.469727915613421 0.000229161507091604 0.743098500788572;0.489521883243695 0.000215581201232987 0.775786369069159;0.490132993385653 0.000209377898530465 0.776832977257392;0.673497387689653 0.000159621578946505 1.08693000471307;0.712441820307218 0.000151056846817968 1.14637457284558;0.713411701708114 0.000147664314508991 1.14790686522368;0.850449494579347 0.000127227690878151 1.38060342649746;0.913538257164073 0.000117417088229601 1.48879838627785;1.25304210010316 9.4537707432015e-05 2.05919101151297;1.43267681331116 8.53578432404767e-05 2.34313440105025;1.90036398259863 7.08930599570862e-05 3.09167639914652;2.70359895198062 5.67035383503415e-05 4.32964034664298;6.16250916115762 3.72403403008622e-05 9.0102242113822];
% e=24 ; gamma=1 ; w=0.64 ; UIC imposed
% init=[0.264852486517957 0.806062297661676 5.88377407373198e-09;0.24325418899597 0.7674580093435 0.000338573931409129;0.246165961325543 0.761994766243078 0.00314687720271695;0.249604401580709 0.756509432001558 0.00746514210732166;0.253579596363966 0.746646558520333 0.0142873490927929;0.257994519242586 0.732003435940188 0.0238853416113763;0.262520135644317 0.713353903442858 0.0358424763984115;0.266874046070717 0.691402981466985 0.0496537154819602;0.271194209073119 0.664571880494595 0.0661814134815264;0.275170205091449 0.632759640110045 0.0853173561830481;0.278745642650971 0.595086299395868 0.107551586775962;0.281459713610388 0.551614693711988 0.132573516872126;0.283721737212554 0.497085546838668 0.163720101218344;0.28514287667638 0.438238680545985 0.197237227492246;0.285290152665816 0.373829299814019 0.233351058090771;0.285915753422514 0.298568637935152 0.276842319305851;0.289592469110139 0.227083155837919 0.321995529246571;0.299237469395389 0.168615408532472 0.36615715940226;0.316474840823719 0.127445316957724 0.408109168379025;0.336742155451897 0.100870883615859 0.444381153539243;0.361739871179307 0.0819068023194802 0.48064859413051;0.389869329828021 0.0685260850734349 0.516431138211932;0.421873330596246 0.0587037963125678 0.553645277885539;0.452992682255124 0.0512601410072162 0.588269601747332;0.493245585441532 0.0452417748341965 0.630945295476236;0.535180999961978 0.0404624200711897 0.674221004874175;0.571811009895003 0.0369792382932897 0.711070174954667;0.611777899032775 0.0335480359480552 0.75097164061954;0.650689213830181 0.0308382895112337 0.789438901723943;0.700315808420316 0.0282200720685325 0.839016055767395;0.755150920520935 0.025753155326516 0.894553233089934;0.822997560576587 0.0237409992359758 0.963777138521058;0.886905777666266 0.0220144807320264 1.02903869283916;0.971090895354308 0.0203403162349268 1.11548090555034;1.03056710379189 0.0191301997471644 1.17571130405676;1.11376900354394 0.0177708772429563 1.26139402601621;1.1763322275537 0.0166457458558107 1.32599751243653;1.25820675954671 0.0154771705763062 1.41391525140866;1.41412261579565 0.0142167794220352 1.58731262421983;1.52986798011711 0.0132875407053759 1.71420144862605;1.61376759172754 0.0124837051247495 1.80749256178425;1.88651028372636 0.0111914232414822 2.12400333962615;2.04672536270493 0.0104814445769427 2.30226066649359;2.1566937698548 0.00991715928390371 2.4259467385436;2.42651454102679 0.00903461208558878 2.74982936723824;2.6553174309856 0.00831621588945775 3.03135413595805;3.23040474354561 0.00723381199059063 3.76351924213943;3.65424266109736 0.00655469252971205 4.29378688530929;4.50629437229414 0.00562995886976705 5.40349621719238;5.89520876561214 0.00465607630937263 7.23061184746713;11.3775076708544 0.00319550075013529 14.0143962647521];
% % e=24 ; gamma=2 ; w=0.51 ; Tol=1e-6
% init=[0.596171586036499 0.933757964300051 6.13775698971239e-08;0.595954373532518 0.932969132002565 3.96200670911718e-05;0.596205628043626 0.932761062127849 0.000147558345315561;0.596506303474665 0.932629216209932 0.000214391754917768;0.596832087748474 0.932472914876312 0.000290664882674552;0.597164724770549 0.932264654919824 0.000398446544729552;0.597480897113209 0.93196391062438 0.000552851569503674;0.597765108428191 0.931634205068981 0.000721474397716978;0.598009859316161 0.931145643452301 0.000970703831384013;0.598206816989566 0.930379656620529 0.00136116883097662;0.598335877489762 0.928685523642331 0.00222153196255616;0.598389414907632 0.926550005642385 0.00330429808027548;0.597712800896106 0.903280749286266 0.0151636983967622;0.564143496648493 0.0461224016314601 0.45029991261429;0.564747538555489 0.0164940200343461 0.467763754901879;0.576105893841686 0.00474878219821241 0.490270907781452;0.586015193851549 0.00309460256831114 0.504999289056661;0.593848805461326 0.002348849805801 0.516442759037952;0.612093794618769 0.00166174066831464 0.542357828484249;0.615354157005532 0.00150924430538745 0.546955723561862;0.622125790853573 0.0013222277255306 0.55679775865349;0.628279219921611 0.00117815123574142 0.566008465616836;0.640910780983541 0.00100348469306001 0.585305550776697;0.641953797445078 0.000951146431855826 0.586943596725175;0.66266047183762 0.000778307231426537 0.620567283381962;0.695360698518184 0.000626745953875603 0.670819950031295;0.697781987635404 0.000602563893013112 0.674429281087258;0.702716455794413 0.000566600981903104 0.682220091834879;0.703630402241958 0.00054317792205145 0.683744523248524;0.71501820223568 0.000488850684963245 0.704504825606513;0.731169075547728 0.00043579905303927 0.735288117079383;0.773209264812081 0.000363420770099389 0.813823408622327;0.786583654433669 0.0003358381641124 0.83823809744933;0.850593393793183 0.000277422881201754 0.950607164355352;0.85167354435632 0.000270477753255105 0.952398446765179;0.892241732342615 0.000241574264817156 1.02341377775113;0.893301197706239 0.000234505449471223 1.02528451186531;0.900332836659925 0.000219647482153012 1.03958951826847;1.00917001730465 0.000177743735802224 1.25551371191146;1.04353750572973 0.000164660685238764 1.31700418190465;1.04422278047299 0.000158505508425798 1.31829485965727;1.21812972415436 0.00012787104302823 1.64680629661575;1.27183867013232 0.000119740651913583 1.73489800310501;1.27297866195603 0.000116044350190365 1.73686614133306;1.40786298933874 0.000101012410798202 1.99346328619608;1.48325082133763 9.19124070758857e-05 2.13716603732768;1.75676827920178 7.63873657199193e-05 2.65231766527801;1.92166380288442 6.84847953976451e-05 2.94045955903102;2.28636137443709 5.73814799935056e-05 3.5917515481274;2.86201894979796 4.63604830083908e-05 4.5805539000503;4.8211968443869 3.19142522714062e-05 7.55919202699836];

x=fmincon(@(x) V(x),init,[],[],[],[],[],ub,@(x) mycon(x),options);

beep

%% Expost check of LDIC binding and UIC satisfied
% LDIC
for r=1:N-1
    K(r)=((x(r,1)-(1/theta)*((((x(r,3)/z(r))+x(r,2))^(1+gamma))/(1+gamma))))-((x(r+1,1)-(1/theta)*((((x(r+1,3)/z(r))+x(r+1,2))^(1+gamma))/(1+gamma))));
end 
nobind1=sum(K<-0.01)
nobind2=sum(K>0.01)
% UIC
for r=2:N-1
    for s=1:N-2
        if r+s<N+1 & x(r+s,1)-(1/theta)*((((x(r+s,3)/z(r-1))+x(r+s,2))^(1+gamma))/(1+gamma))>0
            D(N*r-2*N+s)=((x(r+s,1)-(1/theta)*((((x(r+s,3)/z(r-1))+x(r+s,2))^(1+gamma))/(1+gamma))))-((x(r,1)-(1/theta)*((((x(r,3)/z(r-1))+x(r,2))^(1+gamma))/(1+gamma))));
        else
            D(N*r-2*N+s)=0;
        end
    end  
end
bind=sum(D>0.01)

%% Optimal Allocations

wage=10*[0 z];
earnings=10*n*50*x(:,3)/1000;
consumption=10*n*50*x(:,1)/1000;
care=x(:,2);
formal=10*n*50*w*(1-x(:,2))/1000;

wedge(1)=1-(1/w)*((1/theta)*((x(1,2))^gamma));
for r=2:N
    if x(r,3)>0.08
        wedge(r)=1-(1/z(r-1))*((1/theta)*(((x(r,3)/z(r-1))+x(r,2))^gamma));
    else 
        wedge(r)=1-(1/w)*((1/theta)*((x(r,2))^gamma));
    end
end             
                
for r=1:N
    if care(r,1)<0.99 & x(r,3)>0.08
        subsidy(r)=min(1,max(0,(1-((1/w)*((1/theta)*((x(r,3)/z(50))+x(r,2))^gamma)))));
    else 
        subsidy(r)=0;
    end
end

for r=1:1
    u(r)=cons+x(r,1)-(1/theta)*(((x(r,2))^(1+gamma))/(1+gamma));
end
for r=2:N
    u(r)=cons+x(r,1)-(1/theta)*((((x(r,3)/z(r-1))+x(r,2))^(1+gamma))/(1+gamma));
end

u=u*(10*n*50)/1000;

vec=ones(N,1);

x
init0=mat2str(x)
earnings0=mat2str(earnings)
care0=mat2str(care)
consumption0=mat2str(consumption)
wedge0=mat2str(wedge)
subsidy0=mat2str(subsidy)
u0=mat2str(u)

nowork=x(:,3)<0.08;                                                        % No. unemployed 
firstwork=sum(nowork)+1;                                                   % Index of first z employed - note that this can be done when y is monotonic in z
earn=earnings(firstwork:N);
sub=subsidy(firstwork:N);
earn0=mat2str(earn)
sub0=mat2str(sub)

save '01Baseline.mat'
% save '02e34.mat'
% save '03Highw.mat'
% save '04Gamma2.mat'

beep



