%% Optimal Policy with Unobserved Informal Child Care and Unobserved z
% We have only one dimension of heterogeneity in z (no theta)
% Given current US tax and benefit system, what are the optimal choices of
% agents (private maximization problem)

clc
clear all

global w z pz N p theta gamma zu unem exempt m1 m2 m3 m4 m5 m6 inc1 inc2 inc3 inc4 inc5 ssrate ssbase eitceli eitcmax eitcin eitcout eitcinc dctcinc1 dctcinc2 dctcinc3 dctcinc4 dctcinc5 dctcinc6 dctcinc7 dctcinc8 dctcinc9 dctcinc10 dctcinc11 dctcinc12 dctcinc13 dctcinc14 dctcinc15 dctcrate1 dctcrate2 dctcrate3 dctcrate4 dctcrate5 dctcrate6 dctcrate7 dctcrate8 dctcrate9 dctcrate10 dctcrate11 dctcrate12 dctcrate13 dctcrate14 dctcrate15 dctcrate16 dctcmax ccdfsub ccdfinc1 ccdfinc2 ccdfinc3 ccdfrate1 ccdfrate2 ccdfrate3

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Parameters %% 
%%%%%%%%%%%%%%%%

load ('..\4Optimal_Allocations\01Baseline.mat') 

b=x(:,1);
h=x(:,2);
y=x(:,3);

s=subsidy;

z(50)=0.1*28.8;
for r=1:N
    if care(r,1)<0.99 & x(r,3)>0.08
        s25(r)=min(1,max(0,(1-((1/w)*((1/theta)*((x(r,3)/z(50))+x(r,2))^gamma)))));
    else 
        s25(r)=0;
    end
end

z(50)=0.1*35.6;
for r=1:N
    if care(r,1)<0.99 & x(r,3)>0.08
        s100(r)=min(1,max(0,(1-((1/w)*((1/theta)*((x(r,3)/z(50))+x(r,2))^gamma)))));
    else 
        s100(r)=0;
    end
end

z(50)=0.1*38.8;
for r=1:N
    if care(r,1)<0.99 & x(r,3)>0.08
        s500(r)=min(1,max(0,(1-((1/w)*((1/theta)*((x(r,3)/z(50))+x(r,2))^gamma)))));
    else 
        s500(r)=0;
    end
end

%%%%%%%%%%%%%%%%
%% US System  %%
%%%%%%%%%%%%%%%%

% unem=5500/(10*50*n);                                        % Unemployment insurance benefits for single mother with 2 children
unem=556/(10*50*n);                                        % Unemployment insurance benefits for childless person

% exempt=(8400+3650*3)/(10*50*n);                          % Income tax deductions and allowances for single mother with 2 children
exempt=(5700+3650)/(10*50*n);                              % Income tax deductions and allowances for childless person
m1=0.1;                                                     % Marginal income tax rates
m2=0.15;    
m3=0.25;
m4=0.28;
m5=0.33;
m6=0.35;
inc1=8375/(10*50*n);                                        % Income tax thresholds
inc2=34000/(10*50*n);
inc3=82400/(10*50*n);
inc4=171850/(10*50*n);
inc5=373650/(10*50*n);

ssrate=0.08;                                                % Social Security tax rate for employees (note: employees + employers 15.3%)
ssbase=106800/(10*50*n);

% eitcmax=5036/(10*50*n);                                     % Maximum EITC credit for Single parent with two children
% eitcin=0.4;                                                 % Phase in rate
% eitcout=0.21;                                               % Phase out rate
% eitcinc=40363/(10*50*n);                                    % Earnings threshold  
% eitceli=16420/(10*50*n);                                    % Income where phase out start

eitcmax=457/(10*50*n);                                      % Maximum EITC credit for childless parent
eitcin=0.0765;                                              % Phase in rate
eitcout=0.0765;                                             % Phase out rate
eitcinc=13460/(10*50*n);                                    % Earnings threshold  
eitceli=7486/(10*50*n);                                     % Income where phase out start

dctcinc1=15000/(10*50*n);                                   % DCTC income threshold  
dctcinc2=17000/(10*50*n);
dctcinc3=19000/(10*50*n);
dctcinc4=21000/(10*50*n);
dctcinc5=23000/(10*50*n);
dctcinc6=25000/(10*50*n);
dctcinc7=27000/(10*50*n);
dctcinc8=29000/(10*50*n);
dctcinc9=31000/(10*50*n);
dctcinc10=33000/(10*50*n);
dctcinc11=35000/(10*50*n);
dctcinc12=37000/(10*50*n);
dctcinc13=39000/(10*50*n);
dctcinc14=41000/(10*50*n);
dctcinc15=43000/(10*50*n);
dctcrate1=0.35;                                             % DCTC rates
dctcrate2=0.34;
dctcrate3=0.33;
dctcrate4=0.32;
dctcrate5=0.31;
dctcrate6=0.30;
dctcrate7=0.29;
dctcrate8=0.28;
dctcrate9=0.27;
dctcrate10=0.26;
dctcrate11=0.25;
dctcrate12=0.24;
dctcrate13=0.23;
dctcrate14=0.22;
dctcrate15=0.21;
dctcrate16=0.2;
dctcmax=6000/(10*50*n);                                     % DCTC maximum credit

ccdfsub=0.9;                                                % Recommended subsidy rate according to Federal guidelines
ccdfinc1=17568/(10*50*n);                                   % Income thresholds
ccdfinc2=26325/(10*50*n);
ccdfinc3=32349/(10*50*n);
ccdfrate1=0.39;                                             % Proportion receiving the ccdf subsidy
ccdfrate2=0.24;
ccdfrate3=0.05;

%% Computing the Actual Tax Function based on Second Best Allocations

for r=1:N
    % Defining taxable(r) income
    taxable(r)=max(0,(y(r,1)-exempt));
    % Computing Federal taxes
    if taxable(r)>0.01 & taxable(r)<=inc1
        tax(r)=m1*taxable(r);
    elseif taxable(r)>inc1 & taxable(r)<=inc2
        tax(r)=m2*taxable(r);
    elseif taxable(r)>inc2 & taxable(r)<=inc3
        tax(r)=m3*taxable(r);
    elseif taxable(r)>inc3 & taxable(r)<=inc4
        tax(r)=m4*taxable(r);
    elseif taxable(r)>inc4 & taxable(r)<=inc5
        tax(r)=m5*taxable(r);
    elseif taxable(r)>inc5
        tax(r)=m6*taxable(r);
    else
        tax(r)=0;
    end
    % Computing Social Security tax
    ss(r)=min(ssrate*ssbase,ssrate*y(r,1));
    % Computing EITC benefits - Refundable tax credit
    if y(r,1)>0.001 & y(r,1)<eitceli 
       eitc(r)=min(eitcmax,eitcin*y(r,1));
    elseif y(r,1)>=eitceli & y(r,1)<eitcinc
       eitc(r)=min(eitcmax,(eitcmax-eitcout*(y(r,1)-eitceli)));
    else 
       eitc(r)=0;
    end  
    % Defining net income if agent is employed 
    if y(r,1)>0.08
        T(r)=tax(r)+ss(r)-eitc(r);
    else
        T(r)=-unem;
    end
    % Optimal subsidy
    L(r)=b(r)-y(r)+T(r)+(1-s(r))*w*(1-h(r));
    lump(r)=L(r)*(10*n*50/1000);
    atax(r)=T(r)*(10*n*50/1000);
    % 25 bins
    L25(r)=b(r)-y(r)+T(r)+(1-s25(r))*w*(1-h(r));
    lump25(r)=L25(r)*(10*n*50/1000);
    % 50 bins
    L100(r)=b(r)-y(r)+T(r)+(1-s100(r))*w*(1-h(r));
    lump100(r)=L100(r)*(10*n*50/1000);
    % 500 bins
    L500(r)=b(r)-y(r)+T(r)+(1-s500(r))*w*(1-h(r));
    lump500(r)=L500(r)*(10*n*50/1000);
end

nowork=x(:,3)<0.08;                                                        % No. unemployed 
firstwork=sum(nowork)+1;                                                   % Index of first z employed - note that this can be done when y is monotonic in z
sub25b=s25(firstwork:N);
sub100b=s100(firstwork:N);
sub500b=s500(firstwork:N);

atax0=mat2str(atax)
lump0=mat2str(lump)
sub25=mat2str(sub25b)
lump25=mat2str(lump25)
sub100=mat2str(sub100b)
lump100=mat2str(lump100)
sub500=mat2str(sub500b)
lump500=mat2str(lump500)

%% Graphs

wage=10*[0 z];

%break

%% Sensitivity on Subsidies and Allowances

% Optimal
earn1=[3.84147320572579;4.09049956812132;4.21181354234146;4.49976903855169;4.54158417001067;4.62984692350372;4.7101856070467;4.88401044310247;4.8971313282893;5.25671308662825;5.83840493524603;5.86822308140905;5.91969912263705;5.93113998970425;6.05773205690441;6.32809465705562;7.36434835491543;7.57878409044135;9.1499986744686;9.16347625230005;9.8762446091895;9.89009593170496;9.93393813523746;13.1610006071008;13.7159112825082;13.7241124865142;19.233613817492;20.2523675515223;20.264305037851;24.3430786568322;26.2416181854333;36.2720789305795;41.2726637582036;54.5829619223274;76.1547574761124;158.111966789064];
sub1=[0.816766893607011 0.830100189900356 0.827522494080677 0.817804746127613 0.816358897686596 0.813137108969954 0.8101543827611 0.803498097873389 0.803036327737833 0.788971403927853 0.765984188298802 0.764818943166372 0.762799780875555 0.762365738729361 0.757369071229304 0.746641179255163 0.705375162816311 0.696841412212652 0.634172534396621 0.633640540021373 0.605202517780569 0.604656141450922 0.602917579245974 0.47408000962982 0.451926912657765 0.45160471816837 0.231578122525279 0.190892716614852 0.19041878457338 0.0275142125692598 0 0 0 0 0 0];
earnings1=[4.8628600918165e-07;0.000312717191500251;0.0011621832450945;0.00167367890114293;0.00223447339487019;0.00304379966257918;0.00415620826876371;0.00530884188725298;0.00694448218999454;0.00931949568874446;0.0139546761360431;0.0203163675944693;0.0853603804425694;0.266000346769765;0.293652631099368;3.84147320572579;4.09049956812132;4.21181354234146;4.49976903855169;4.54158417001067;4.62984692350372;4.7101856070467;4.88401044310247;4.8971313282893;5.25671308662825;5.83840493524603;5.86822308140905;5.91969912263705;5.93113998970425;6.05773205690441;6.32809465705562;7.36434835491543;7.57878409044135;9.1499986744686;9.16347625230005;9.8762446091895;9.89009593170496;9.93393813523746;13.1610006071008;13.7159112825082;13.7241124865142;19.233613817492;20.2523675515223;20.264305037851;24.3430786568322;26.2416181854333;36.2720789305795;41.2726637582036;54.5829619223274;76.1547574761124;158.111966789064];
lump1=[6.88958800275866 6.89069701471724 6.89255891812952 6.8948185781009 6.89734070368618 6.89992788401014 6.90242858289603 6.90473213274534 6.90678128435326 6.90850715871076 6.90980052872145 6.91056030137146 6.90713860341548 6.89313473287699 6.890777008636 2.17647000095626 1.97369768685818 1.95448730280615 1.94159426801746 1.94025735202132 1.93703109117324 1.93304768409301 1.92336663352127 1.9221763402861 1.89250678453775 1.86049745851045 1.85921250028418 1.85550018324353 1.85429681719589 1.84273504627434 1.81796011942714 1.73355353699263 1.72542250722318 1.76587962151248 1.7666223082103 1.83738516906155 1.83897247271067 1.84141197760534 2.06999264261311 2.11273750382761 2.11282368029259 2.724205613359 2.86223933857182 2.86356989029572 3.13871066109534 2.95912578795933 1.24042916593482 0.570798649777122 3.21794327153636 2.84003285156325 9.00352179844375];

% USA
subUSA=[0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.701 0.536 0.536 0.536 0.516 0.506 0.24 0.21 0.2 0.2 0.2];
atax0=[-0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 -0.556 0.0134451562200403 0.0143167484884246 0.0147413473981951 0.015749191634931 0.0158955445950374 0.016204464232263 0.0164856496246634 0.0170940365508586 0.0171399596490125 0.0183984958031989 0.0204344172733611 0.0205387807849317 0.0207189469292297 0.0207589899639649 0.0276185645523525 0.04924757256445 0.132147868393234 0.156400710154072 0.402295792554336 0.404405033484957 0.568577742257106 0.572130606482322 0.58337613168841 1.41111765572136 1.53386403085148 1.53534024757255 3.02123117802316 3.25554453685014 3.25829015870573 4.19640809107142 4.63307218264965 6.94007815403328 8.09021266438683 15.674877434368 22.7935699671171 50.1973507009378];
atax2=[-5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -5.5 -1.22927142583225 -1.30895986179882 -1.34778033354927 -1.43992609233654 -1.45330693440341 -1.48155101552119 -1.50725939425494 -1.56288334179279 -1.56708202505258 -1.68214818772104 -1.86828957927873 -1.8778313860509 -1.89430371924386 -1.89796479670536 -1.93847425820941 -2.0249902902578 -2.35659147357294 -2.42521090894123 -2.92799957582995 -2.93231240073601 -3.16039827494064 -3.16483069814559 -3.17886020327599 -3.98311995143193 -3.93872709739934 -3.93807100107887 -2.90645199292732 -2.52077665490629 -2.51612103523811 -0.925399323835424 -0.184968907681025 4.57301472945497 6.59021266438683 13.174877434368 20.2935699671171 47.3973507009378];
Alump1=atax0-atax2;

% Wage bins
sub25=[0.798598612884918 0.810754136845383 0.80760268553631 0.796523049575588 0.794879436108996 0.791240207936997 0.78787751923009 0.780399128278167 0.779875302802737 0.764109733959413 0.738371401705706 0.737065131393328 0.7348025127207 0.734314360894846 0.728718975119037 0.716712400891176 0.670545413633638 0.66099748736579 0.590897536597146 0.59030179990108 0.558492733557068 0.55788084727789 0.555934932992478 0.411834943529387 0.387057391722801 0.386696409568191 0.140612579770569 0.0951089692716122 0.0945785787853924 0 0 0 0 0 0 0];
lump25=[6.88958800275866 6.89069701471724 6.89255891812952 6.8948185781009 6.89734070368618 6.89992788401014 6.90242858289603 6.90473213274534 6.90678128435326 6.90850715871076 6.90980052872145 6.91056030137146 6.90713860341548 6.89313473287699 6.890777008636 2.28551458815784 2.0915964629651 2.07606175180577 2.07163111474472 2.07152170405978 2.07087285016399 2.069231897742 2.06460287350668 2.06379773393209 2.04455641196718 2.02939958148632 2.0289800875934 2.02676107870529 2.02589125707105 2.01799874368541 2.0010544964662 1.94664787792411 1.94472625473857 2.03066467113758 2.03179846761122 2.12319379394473 2.12518322112117 2.1288938428256 2.45087968039944 2.50968716546605 2.51001207990053 3.2808607038962 3.44838199202227 3.45005914005114 3.30708454566682 2.95912578795933 1.24042916593482 0.570798649777122 3.21794327153636 2.84003285156325 9.00352179844375];

sub100=[0.831378623676036 0.845659136256604 0.843542879824883 0.834920422078775 0.833633624965454 0.830747559410246 0.828070415746203 0.822075304696684 0.821663442193525 0.808966251882965 0.788191605187803 0.787139778704823 0.785316414739067 0.784925889976019 0.780410738034122 0.770711218541737 0.733386778291308 0.725668672341889 0.668976190078507 0.668495460079896 0.642768579704428 0.642274889356137 0.640703088809892 0.524140228199768 0.50409783318169 0.503806833437842 0.304736611027601 0.267926217064745 0.26749769138656 0.120107463994914 0.0515023105610926 0 0 0 0 0];
lump100=[6.88958800275866 6.89069701471724 6.89255891812952 6.8948185781009 6.89734070368618 6.89992788401014 6.90242858289603 6.90473213274534 6.90678128435326 6.90850715871076 6.90980052872145 6.91056030137146 6.90713860341548 6.89313473287699 6.890777008636 2.08877155012045 1.87887830805763 1.85671178627569 1.83701291921126 1.83468878948039 1.82938966465354 1.82352235255838 1.80977824031017 1.80827818956907 1.770221789767 1.72465894595336 1.72267794326275 1.71776464215716 1.716293025029 1.70178027588951 1.67070757223384 1.56217369998133 1.54904879245973 1.55292784414751 1.55335598316967 1.60752530823752 1.60878920646785 1.61020642334339 1.76366654230375 1.79349313527277 1.79338730816729 2.27651911792812 2.39083764871652 2.39188945245493 2.57208403536883 2.64395429870169 1.24042916593482 0.570798649777122 3.21794327153636 2.84003285156325 9.00352179844375];

sub500=[0.842828766923874 0.857851543570651 0.856096883409005 0.848332724420701 0.847170564190027 0.844547580300841 0.842109899307926 0.836632901796178 0.836260148251193 0.824634750563357 0.805593932177305 0.804630983587432 0.802961052436204 0.802604629060771 0.798466805613921 0.789573146356608 0.75533743083395 0.748258485893274 0.696249267340644 0.69580870948135 0.672206352524853 0.671753948323433 0.670312826681832 0.563368756986997 0.544980364582733 0.544713809877453 0.362065563122234 0.328291732364226 0.327898788329115 0.192666017129854 0.129719773286177 0 0 0 0 0];
lump500=[6.88958800275866 6.89069701471724 6.89255891812952 6.8948185781009 6.89734070368618 6.89992788401014 6.90242858289603 6.90473213274534 6.90678128435326 6.90850715871076 6.90980052872145 6.91056030137146 6.90713860341548 6.89313473287699 6.890777008636 2.02004869389878 1.80457530185587 1.78009227133006 1.7550601717114 1.75196243484259 1.74503895825328 1.73769536770346 1.72076733144347 1.71902454641983 1.67439599086628 1.61821224730753 1.61568580552202 1.60983138111912 1.60814955525566 1.59132434050416 1.55531653017329 1.42787586705529 1.41083762310097 1.38605312471374 1.38623477574801 1.42740096150172 1.42841143057924 1.42902755516768 1.52362120116177 1.54332469294935 1.54306840670073 1.92569998298718 2.02143465190384 2.02226802125092 2.12806022696568 2.16529782786673 1.24042916593482 0.570798649777122 3.21794327153636 2.84003285156325 9.00352179844375];

figure(3) 
subplot(2,2,2)
hold on
h1 = plot (earnings1,lump1,'-k','LineWidth',1.5);
hold on
h2 = plot (earnings1,Alump1,'bo','MarkerSize',3);
hold on
plot (earnings1,lump25,':','LineWidth',1.2,'Color',[0 0.4 0.6]);
hold on
plot (earnings1,lump100,'--','LineWidth',1.2,'Color',[0.3 0.5 0.3]);
hold on
plot (earnings1,lump500,'-.','LineWidth',1.2,'Color',[0.8 0 0.8]);
hold on
title('(b) Child Allowances')
xlabel('Earnings ($000)')
ylabel('Amount ($000)')
legend([h1 h2],{'Baseline','USA'})
hold on
subplot(2,2,1)
hold on
plot (earn1,sub1,'-k','LineWidth',1.5);
hold on
plot (earn1,subUSA,'bo','MarkerSize',3);
hold on
h3 = plot (earn1,sub25,':','LineWidth',1.2,'Color',[0 0.4 0.6]);
hold on
h4 = plot (earn1,sub100,'--','LineWidth',1.2,'Color',[0.3 0.5 0.3]);
hold on
h5 = plot (earn1,sub500,'-.','LineWidth',1.2,'Color',[0.8 0 0.8]);
hold on
title('(a) Child Care Subsidy')
xlabel('Earnings ($000)')
ylabel('Rate')
legend([h3 h4 h5],{'25 bins', '100 bins','500 bins'})
hold off



